==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/deviceupdate/kotlin/inputs/PrivateLinkServiceConnectionStateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.deviceupdate.kotlin.inputs

import com.pulumi.azurenative.deviceupdate.inputs.PrivateLinkServiceConnectionStateArgs.builder
import com.pulumi.azurenative.deviceupdate.kotlin.enums.PrivateEndpointServiceConnectionStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A collection of information about the state of the connection between service consumer and provider.
 * @property actionsRequired A message indicating if changes on the service provider require any updates on the consumer.
 * @property description The reason for approval/rejection of the connection.
 * @property status Indicates whether the connection has been Approved/Rejected/Removed by the owner of the service.
 */
public data class PrivateLinkServiceConnectionStateArgs(
    public val actionsRequired: Output<String>? = null,
    public val description: Output<String>? = null,
    public val status: Output<Either<String, PrivateEndpointServiceConnectionStatus>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.deviceupdate.inputs.PrivateLinkServiceConnectionStateArgs> {
    override fun toJava():
        com.pulumi.azurenative.deviceupdate.inputs.PrivateLinkServiceConnectionStateArgs =
        com.pulumi.azurenative.deviceupdate.inputs.PrivateLinkServiceConnectionStateArgs.builder()
            .actionsRequired(actionsRequired?.applyValue({ args0 -> args0 }))
            .description(description?.applyValue({ args0 -> args0 }))
            .status(
                status?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [PrivateLinkServiceConnectionStateArgs].
 */
@PulumiTagMarker
public class PrivateLinkServiceConnectionStateArgsBuilder internal constructor() {
    private var actionsRequired: Output<String>? = null

    private var description: Output<String>? = null

    private var status: Output<Either<String, PrivateEndpointServiceConnectionStatus>>? = null

    /**
     * @param value A message indicating if changes on the service provider require any updates on the consumer.
     */
    @JvmName("ghidsnnyutiplgyg")
    public suspend fun actionsRequired(`value`: Output<String>) {
        this.actionsRequired = value
    }

    /**
     * @param value The reason for approval/rejection of the connection.
     */
    @JvmName("djgxbswyfiouhbrg")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Indicates whether the connection has been Approved/Rejected/Removed by the owner of the service.
     */
    @JvmName("pvfeufscwbwoornx")
    public suspend
    fun status(`value`: Output<Either<String, PrivateEndpointServiceConnectionStatus>>) {
        this.status = value
    }

    /**
     * @param value A message indicating if changes on the service provider require any updates on the consumer.
     */
    @JvmName("rgrhoykwcbigmhab")
    public suspend fun actionsRequired(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actionsRequired = mapped
    }

    /**
     * @param value The reason for approval/rejection of the connection.
     */
    @JvmName("kieakcxtassdnfpe")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Indicates whether the connection has been Approved/Rejected/Removed by the owner of the service.
     */
    @JvmName("qfmwjeuyldvdvvos")
    public suspend fun status(`value`: Either<String, PrivateEndpointServiceConnectionStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Indicates whether the connection has been Approved/Rejected/Removed by the owner of the service.
     */
    @JvmName("xeodtmlfolpeehrl")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PrivateEndpointServiceConnectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Indicates whether the connection has been Approved/Rejected/Removed by the owner of the service.
     */
    @JvmName("veidpqybioyjijng")
    public fun status(`value`: PrivateEndpointServiceConnectionStatus) {
        val toBeMapped = Either.ofRight<String, PrivateEndpointServiceConnectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): PrivateLinkServiceConnectionStateArgs =
        PrivateLinkServiceConnectionStateArgs(
            actionsRequired = actionsRequired,
            description = description,
            status = status,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/deviceupdate/kotlin/inputs/PrivateLinkServiceConnectionStateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.deviceupdate.kotlin.inputs

import com.pulumi.azurenative.deviceupdate.inputs.PrivateLinkServiceConnectionStateArgs.builder
import com.pulumi.azurenative.deviceupdate.kotlin.enums.PrivateEndpointServiceConnectionStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A collection of information about the state of the connection between service consumer and provider.
 * @property actionsRequired A message indicating if changes on the service provider require any updates on the consumer.
 * @property description The reason for approval/rejection of the connection.
 * @property status Indicates whether the connection has been Approved/Rejected/Removed by the owner of the service.
 */
public data class PrivateLinkServiceConnectionStateArgs(
    public val actionsRequired: Output<String>? = null,
    public val description: Output<String>? = null,
    public val status: Output<Either<String, PrivateEndpointServiceConnectionStatus>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.deviceupdate.inputs.PrivateLinkServiceConnectionStateArgs> {
    override fun toJava():
        com.pulumi.azurenative.deviceupdate.inputs.PrivateLinkServiceConnectionStateArgs =
        com.pulumi.azurenative.deviceupdate.inputs.PrivateLinkServiceConnectionStateArgs.builder()
            .actionsRequired(actionsRequired?.applyValue({ args0 -> args0 }))
            .description(description?.applyValue({ args0 -> args0 }))
            .status(
                status?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [PrivateLinkServiceConnectionStateArgs].
 */
@PulumiTagMarker
public class PrivateLinkServiceConnectionStateArgsBuilder internal constructor() {
    private var actionsRequired: Output<String>? = null

    private var description: Output<String>? = null

    private var status: Output<Either<String, PrivateEndpointServiceConnectionStatus>>? = null

    /**
     * @param value A message indicating if changes on the service provider require any updates on the consumer.
     */
    @JvmName("adcruwlhkykmceby")
    public suspend fun actionsRequired(`value`: Output<String>) {
        this.actionsRequired = value
    }

    /**
     * @param value The reason for approval/rejection of the connection.
     */
    @JvmName("kndcgwqhygefxkpr")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Indicates whether the connection has been Approved/Rejected/Removed by the owner of the service.
     */
    @JvmName("batslucqumeimpft")
    public suspend
    fun status(`value`: Output<Either<String, PrivateEndpointServiceConnectionStatus>>) {
        this.status = value
    }

    /**
     * @param value A message indicating if changes on the service provider require any updates on the consumer.
     */
    @JvmName("psyvjwhwhxfttrrl")
    public suspend fun actionsRequired(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actionsRequired = mapped
    }

    /**
     * @param value The reason for approval/rejection of the connection.
     */
    @JvmName("hgfhtsquluqqbabl")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Indicates whether the connection has been Approved/Rejected/Removed by the owner of the service.
     */
    @JvmName("orkvuwgpmyeipjhq")
    public suspend fun status(`value`: Either<String, PrivateEndpointServiceConnectionStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Indicates whether the connection has been Approved/Rejected/Removed by the owner of the service.
     */
    @JvmName("vgqxkynilktafljy")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PrivateEndpointServiceConnectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Indicates whether the connection has been Approved/Rejected/Removed by the owner of the service.
     */
    @JvmName("arhoiapyyswljvto")
    public fun status(`value`: PrivateEndpointServiceConnectionStatus) {
        val toBeMapped = Either.ofRight<String, PrivateEndpointServiceConnectionStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): PrivateLinkServiceConnectionStateArgs =
        PrivateLinkServiceConnectionStateArgs(
            actionsRequired = actionsRequired,
            description = description,
            status = status,
        )
}
